# What's Changed

1. 优化：强化了 WebUI 安全性
2. 修复：测试文本生成提供商时可能出现的误报
3. 修复：刷新知识库页面时出现404
4. 新增：WeChatPadPro 支持获取引用、语音收发、视频等消息段
5. 优化：WebUI 账户修改页面的设计逻辑
6. 优化：插件更新后自动刷新插件列表
7. 新增：支持下载插件的指定分支
8. 修复：WeChatPadPro 群聊模式下 @ 不回复等问题
9. 其他更新、优化及修复
